# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/modelmanager/v1/model.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n+public/llmcloud/modelmanager/v1/model.proto\x12\x1fpublic.llmcloud.modelmanager.v1"\xd3\x01\n\x0cModelDetails\x12\x16\n\x06\x66\x61mily\x18\x01 \x01(\tR\x06\x66\x61mily\x12\x18\n\x07version\x18\x02 \x01(\tR\x07version\x12\x12\n\x04size\x18\x03 \x01(\tR\x04size\x12\'\n\x0fsequence_length\x18\x04 \x01(\rR\x0esequenceLength\x12\x10\n\x03tag\x18\x05 \x01(\tR\x03tag\x12\x18\n\x07license\x18\x06 \x01(\tR\x07license\x12\x12\n\x04name\x18\x07 \x01(\tR\x04name\x12\x14\n\x05owner\x18\x08 \x01(\tR\x05owner"%\n\tModelMeta\x12\x18\n\x07\x63reated\x18\x01 \x01(\rR\x07\x63reated"\xe6\x01\n\x05Model\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12G\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32-.public.llmcloud.modelmanager.v1.ModelDetailsR\x07\x64\x65tails\x12>\n\x04meta\x18\x03 \x01(\x0b\x32*.public.llmcloud.modelmanager.v1.ModelMetaR\x04meta\x12\x44\n\x06status\x18\x04 \x01(\x0e\x32,.public.llmcloud.modelmanager.v1.ModelStatusR\x06status*_\n\x0bModelStatus\x12\x1c\n\x18MODEL_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13MODEL_STATUS_ACTIVE\x10\x01\x12\x19\n\x15MODEL_STATUS_INACTIVE\x10\x02\x42\x9d\x02\n#com.public.llmcloud.modelmanager.v1B\nModelProtoP\x01ZIgit.groq.io/cloud/go-proto/public/llmcloud/modelmanager/v1;modelmanagerv1\xa2\x02\x03PLM\xaa\x02\x1fPublic.Llmcloud.Modelmanager.V1\xca\x02 Public_\\Llmcloud\\Modelmanager\\V1\xe2\x02,Public_\\Llmcloud\\Modelmanager\\V1\\GPBMetadata\xea\x02"Public::Llmcloud::Modelmanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.modelmanager.v1.model_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b'\n#com.public.llmcloud.modelmanager.v1B\nModelProtoP\001ZIgit.groq.io/cloud/go-proto/public/llmcloud/modelmanager/v1;modelmanagerv1\242\002\003PLM\252\002\037Public.Llmcloud.Modelmanager.V1\312\002 Public_\\Llmcloud\\Modelmanager\\V1\342\002,Public_\\Llmcloud\\Modelmanager\\V1\\GPBMetadata\352\002"Public::Llmcloud::Modelmanager::V1'
    _globals["_MODELSTATUS"]._serialized_start = 566
    _globals["_MODELSTATUS"]._serialized_end = 661
    _globals["_MODELDETAILS"]._serialized_start = 81
    _globals["_MODELDETAILS"]._serialized_end = 292
    _globals["_MODELMETA"]._serialized_start = 294
    _globals["_MODELMETA"]._serialized_end = 331
    _globals["_MODEL"]._serialized_start = 334
    _globals["_MODEL"]._serialized_end = 564
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/protobuf/duration.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1egoogle/protobuf/duration.proto\x12\x0fgoogle.protobuf":\n\x08\x44uration\x12\x18\n\x07seconds\x18\x01 \x01(\x03R\x07seconds\x12\x14\n\x05nanos\x18\x02 \x01(\x05R\x05nanosB\x83\x01\n\x13\x63om.google.protobufB\rDurationProtoP\x01Z1google.golang.org/protobuf/types/known/durationpb\xf8\x01\x01\xa2\x02\x03GPB\xaa\x02\x1eGoogle.Protobuf.WellKnownTypesb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "google.protobuf.duration_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\023com.google.protobufB\rDurationProtoP\001Z1google.golang.org/protobuf/types/known/durationpb\370\001\001\242\002\003GPB\252\002\036Google.Protobuf.WellKnownTypes"
    _globals["_DURATION"]._serialized_start = 51
    _globals["_DURATION"]._serialized_end = 109
# @@protoc_insertion_point(module_scope)



import os

from groq.cloud.core.exceptions import AuthTokenError
import requests


class Auth:
    _grpc_channel = None
    _grpc_channel_async = None
    _groq_access_key = ""
    _VALIDATION_URL = "https://api.groq.com/v1/request_manager/ping"

    def __init__(self):
        return

    def _verify_token_validity(self):
        headers = {
            "Authorization": "Bearer " + self._groq_access_key,
        }

        try:
            auth_resp = requests.post(url=self._VALIDATION_URL, headers=headers)
            if not auth_resp.status_code == 404:
                raise AuthTokenError
        except Exception:
            raise AuthTokenError

        return True

    def get_token(self):
        self._groq_access_key = os.environ.get("GROQ_SECRET_ACCESS_KEY")
        try:
            self._verify_token_validity()
        except Exception:
            raise AuthTokenError

        return self._groq_access_key



import os
import sys
from datetime import datetime
from typing import Any, Literal, Union

import grpc
import requests

from groq.cloud.core.auth import Auth
from groq.cloud.core.exceptions import *
from groq.cloud.core.types import GroqListModelsResponse
from public.llmcloud.modelmanager.v1 import modelmanager_pb2, modelmanager_pb2_grpc
from public.llmcloud.requestmanager.v1 import (
    requestmanager_pb2,
    requestmanager_pb2_grpc,
)


class GroqGrpcConnection:
    _grpc_channel = None
    _grpc_channel_async = None
    _auth_token = ""
    _auth_expiry_time = ""
    _API_URL = "api.groq.com:443"
    auth_client: Auth

    def _get_grpc_credentials(self):
        self._auth_token = self.auth_client.get_token()

        credentials = grpc.ssl_channel_credentials()
        call_credentials = grpc.access_token_call_credentials(self._auth_token)
        credentials = grpc.composite_channel_credentials(credentials, call_credentials)
        return credentials

    def _open_grpc_channel(self) -> grpc.secure_channel:
        credentials = self._get_grpc_credentials()
        query_channel = grpc.secure_channel(self._API_URL, credentials)
        return query_channel

    def _open_grpc_channel_async(self) -> grpc.aio.secure_channel:
        credentials = self._get_grpc_credentials()
        query_channel = grpc.aio.secure_channel(self._API_URL, credentials)
        return query_channel

    def __init__(self):
        self.auth_client = Auth()

    def __del__(self):
        if self._grpc_channel is not None:
            self._grpc_channel.close()
            self._grpc_channel = None

    def get_grpc_channel(self):
        if self._grpc_channel is None:
            self._grpc_channel = self._open_grpc_channel()

        return self._grpc_channel

    async def __aexit__(self):
        if self._grpc_channel_async is not None:
            self._grpc_channel_async.aio.close()
            self._grpc_channel_async = None

    def get_grpc_channel_async(self):
        if self._grpc_channel_async is None:
            self._grpc_channel_async = self._open_grpc_channel_async()

        return self._grpc_channel_async


grpc_connection = GroqGrpcConnection()


class Models:
    def __init__(self):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel()
        self._stub = modelmanager_pb2_grpc.ModelManagerServiceStub(self._query_channel)

    def list_models(self):
        request = modelmanager_pb2.ListModelsRequest()
        resp = self._stub.ListModels(request)

        models = []

        try:
            for model in resp.models:
                details = GroqListModelsResponse.Details(
                    family=model.details.family,
                    version=model.details.version,
                    size=model.details.size,
                    sequence_length=model.details.sequence_length,
                    tag=model.details.tag,
                    name=model.details.name,
                    owner=model.details.owner,
                )
                meta = GroqListModelsResponse.Meta(created=model.meta.created)
                response = GroqListModelsResponse(
                    id=model.id,
                    details=details,
                    meta=meta,
                    status=model.status,
                )

                models.append(response)
        except Exception as e:
            raise e

        return models


class ChatCompletion:
    def __init__(self, model):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel()
        self._stub = requestmanager_pb2_grpc.RequestManagerServiceStub(
            self._query_channel
        )
        self._model = model
        self._system_prompt = "Give useful and accurate answers."
        self._lastmessages = []
        self._history_index = 0

    def __del__(self):
        self._lastmessages = []

    def __enter__(self):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel()
        return self

    def __exit__(self, *args: object) -> None:
        self._lastmessages = []
        return None

    def _update_history(self, user_prompt, response):
        self._lastmessages.append({"user_prompt": user_prompt, "last_resp": response})

    def _resp_generator(self, resp_stream):
        for response in resp_stream:
            self._lastmessages[-1]["last_resp"] += response.content
            yield response

    def clear_history(self):
        self._lastmessages = []

    def update_history(self, history_pairs):
        for pair in history_pairs:
            self._update_history(pair[0], pair[1])

    def set_system_prompt(self, system_prompt):
        self._system_prompt = system_prompt

    def send_chat(
        self,
        user_prompt="Write multiple paragraphs",
        streaming=False,
        seed=1234,
        max_tokens=2048,
        temperature=0.7,
        top_p=0.3,
        top_k=40,
    ) -> Union[tuple[Literal[""], Literal[""], dict], Any]:
        # Generate request
        request = requestmanager_pb2.GetTextCompletionRequest()
        request.user_prompt = user_prompt

        history_messages = -1
        for msg in self._lastmessages:
            history_messages += 1
            req = request.history.add()
            req.user_prompt = msg["user_prompt"]
            req.assistant_response = msg["last_resp"]

        self._history_index = history_messages

        request.model_id = self._model
        request.system_prompt = self._system_prompt
        request.seed = seed
        request.max_tokens = max_tokens
        request.temperature = temperature
        request.top_p = top_p
        request.top_k = top_k

        try:
            if streaming == True:
                resp_stream = self._stub.GetTextCompletionStream(request)
            else:
                resp = self._stub.GetTextCompletion(request)
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.INVALID_ARGUMENT:
                raise InvalidArgumentError(e)
            elif e.code() == grpc.StatusCode.UNAVAILABLE:
                raise ModelUnavailableError(e)
            else:
                raise e

        if streaming == True:
            self._update_history(user_prompt, "")
            return self._resp_generator(resp_stream=resp_stream)
        else:
            self._update_history(user_prompt, resp.content)
            return resp.content, resp.request_id, resp.stats


class Completion:
    def __init__(self):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel()
        self._stub = requestmanager_pb2_grpc.RequestManagerServiceStub(
            self._query_channel
        )

    def __del__(self):
        return

    def __enter__(self):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel()
        return self

    def __exit__(self, *args: object) -> None:
        return None

    def _resp_generator(self, resp_stream):
        for response in resp_stream:
            yield response

    def send_prompt(
        self,
        model,
        user_prompt="Write multiple paragraphs",
        system_prompt="Give useful and accurate answers.",
        streaming=False,
        seed=1234,
        max_tokens=2048,
        temperature=0.7,
        top_p=0.3,
        top_k=40,
    ) -> Union[tuple[Literal[""], Literal[""], dict], Any]:
        # Generate request
        request = requestmanager_pb2.GetTextCompletionRequest()
        request.user_prompt = user_prompt
        request.model_id = model
        request.system_prompt = system_prompt
        request.seed = seed
        request.max_tokens = max_tokens
        request.temperature = temperature
        request.top_p = top_p
        request.top_k = top_k

        try:
            if streaming == True:
                resp_stream = self._stub.GetTextCompletionStream(request)
            else:
                resp = self._stub.GetTextCompletion(request)
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.INVALID_ARGUMENT:
                raise InvalidArgumentError(e)
            elif e.code() == grpc.StatusCode.UNAVAILABLE:
                raise ModelUnavailableError(e)
        except grpc._channel._MultiThreadedRendezvous as e:
            # TODO: this is broken somehow, as if what is being raised isn't an exception?
            raise InvalidArgumentError(e)
        except Exception as e:
            raise e

        if streaming == True:
            return self._resp_generator(resp_stream=resp_stream)
        else:
            return resp.content, resp.request_id, resp.stats


class AsyncCompletion:
    def __init__(
        self,
        model,
        user_prompt="Write multiple paragraphs",
        system_prompt="Give useful and accurate answers.",
        streaming=False,
        seed=1234,
        max_tokens=2048,
        temperature=0.7,
        top_p=0.3,
        top_k=40,
    ):
        global grpc_connection
        self._query_channel_async = grpc_connection.get_grpc_channel_async()
        self._stub = requestmanager_pb2_grpc.RequestManagerServiceStub(
            self._query_channel_async
        )

    async def __aenter__(self):
        global grpc_connection
        self._query_channel_async = grpc_connection.get_grpc_channel_async()
        return self

    async def __aexit__(self, *args: object) -> None:
        return None

    async def _resp_generator(self, resp_stream):
        async for response in resp_stream:
            yield response

    async def send_prompt(
        self,
        model,
        user_prompt="Write multiple paragraphs",
        system_prompt="Give useful and accurate answers.",
        streaming=False,
        seed=1234,
        max_tokens=2048,
        temperature=0.7,
        top_p=0.3,
        top_k=40,
    ) -> Union[tuple[Literal[""], Literal[""], dict], Any]:
        # Generate request
        request = requestmanager_pb2.GetTextCompletionRequest()
        request.user_prompt = user_prompt
        request.model_id = model
        request.system_prompt = system_prompt
        request.seed = seed
        request.max_tokens = max_tokens
        request.temperature = temperature
        request.top_p = top_p
        request.top_k = top_k

        try:
            if streaming == True:
                resp_stream = self._stub.GetTextCompletionStream(request)
            else:
                resp = await self._stub.GetTextCompletion(request)
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.INVALID_ARGUMENT:
                raise InvalidArgumentError(e)
            elif e.code() == grpc.StatusCode.UNAVAILABLE:
                raise ModelUnavailableError(e)
            else:
                raise e

        if streaming == True:
            return self._resp_generator(resp_stream=resp_stream)
        else:
            return resp.content, resp.request_id, resp.stats


class AsyncChatCompletion:
    def __init__(self, model):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel_async()
        self._stub = requestmanager_pb2_grpc.RequestManagerServiceStub(
            self._query_channel
        )
        self._model = model
        self._system_prompt = "Give useful and accurate answers."
        self._lastmessages = []
        self._history_index = 0

    def __del__(self):
        self._lastmessages = []

    async def __aenter__(self):
        global grpc_connection
        self._query_channel = grpc_connection.get_grpc_channel_async()
        return self

    async def __aexit__(self, *args: object) -> None:
        self._lastmessages = []
        return None

    def _update_history(self, user_prompt, response):
        self._lastmessages.append({"user_prompt": user_prompt, "last_resp": response})

    async def _resp_generator(self, resp_stream):
        async for response in resp_stream:
            if self._history_index > -1:
                self._lastmessages[self._history_index]["last_resp"] += response.content
            yield response

    async def send_chat(
        self,
        user_prompt="Write multiple paragraphs",
        streaming=False,
        seed=1234,
        max_tokens=2048,
        temperature=0.7,
        top_p=0.3,
        top_k=40,
    ) -> Union[tuple[Literal[""], Literal[""], dict], Any]:
        # Generate request
        request = requestmanager_pb2.GetTextCompletionRequest()
        request.user_prompt = user_prompt

        history_messages = -1
        for msg in self._lastmessages:
            history_messages += 1
            req = request.history.add()
            req.user_prompt = msg["user_prompt"]
            req.assistant_response = msg["last_resp"]

        self._history_index = history_messages

        request.model_id = self._model
        request.system_prompt = self._system_prompt
        request.seed = seed
        request.max_tokens = max_tokens
        request.temperature = temperature
        request.top_p = top_p
        request.top_k = top_k

        try:
            if streaming == True:
                resp_stream = self._stub.GetTextCompletionStream(request)
            else:
                resp = await self._stub.GetTextCompletion(request)
        except grpc.RpcError as e:
            if e.code() == grpc.StatusCode.INVALID_ARGUMENT:
                raise InvalidArgumentError(e)
            elif e.code() == grpc.StatusCode.UNAVAILABLE:
                raise ModelUnavailableError(e)
            else:
                raise e

        if streaming == True:
            self._update_history(user_prompt, "")
            return self._resp_generator(resp_stream=resp_stream)
        else:
            self._update_history(user_prompt, resp.content)
            return resp.content, resp.request_id, resp.stats



from dataclasses import dataclass


@dataclass
class GroqListModelsResponse:
    @dataclass
    class Details:
        family: str
        version: str
        size: str
        sequence_length: str
        tag: str
        name: str
        owner: str

    @dataclass
    class Meta:
        created: int

    id: str
    details: Details
    meta: Meta
    status: str



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buf/validate/expression.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1d\x62uf/validate/expression.proto\x12\x0c\x62uf.validate"V\n\nConstraint\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1e\n\nexpression\x18\x03 \x01(\tR\nexpression"E\n\nViolations\x12\x37\n\nviolations\x18\x01 \x03(\x0b\x32\x17.buf.validate.ViolationR\nviolations"\x82\x01\n\tViolation\x12\x1d\n\nfield_path\x18\x01 \x01(\tR\tfieldPath\x12#\n\rconstraint_id\x18\x02 \x01(\tR\x0c\x63onstraintId\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\x17\n\x07\x66or_key\x18\x04 \x01(\x08R\x06\x66orKeyB\xbd\x01\n\x10\x63om.buf.validateB\x0f\x45xpressionProtoP\x01ZGbuf.build/gen/go/bufbuild/protovalidate/protocolbuffers/go/buf/validate\xa2\x02\x03\x42VX\xaa\x02\x0c\x42uf.Validate\xca\x02\x0c\x42uf\\Validate\xe2\x02\x18\x42uf\\Validate\\GPBMetadata\xea\x02\rBuf::Validateb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "buf.validate.expression_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\020com.buf.validateB\017ExpressionProtoP\001ZGbuf.build/gen/go/bufbuild/protovalidate/protocolbuffers/go/buf/validate\242\002\003BVX\252\002\014Buf.Validate\312\002\014Buf\\Validate\342\002\030Buf\\Validate\\GPBMetadata\352\002\rBuf::Validate"
    _globals["_CONSTRAINT"]._serialized_start = 47
    _globals["_CONSTRAINT"]._serialized_end = 133
    _globals["_VIOLATIONS"]._serialized_start = 135
    _globals["_VIOLATIONS"]._serialized_end = 204
    _globals["_VIOLATION"]._serialized_start = 207
    _globals["_VIOLATION"]._serialized_end = 337
# @@protoc_insertion_point(module_scope)



from __future__ import annotations

from typing import Any, Optional, cast

import grpc
from typing_extensions import Literal


class GroqError(Exception):
    pass


class APIError(GroqError):
    message: str
    error_code: Optional[Literal]
    # body: object | None

    def __init__(self, message: str, error_code=None):
        super().__init__(message)
        self.message = message
        self.error_code = error_code


class APIStatusError(APIError):
    """Raised when an API response has a status code of 4xx or 5xx, or is in Maintenance mode"""

    pass


class AuthenticationError(APIStatusError):
    status_code: Literal[401] = 401
    message = "Token is invalid for this request"

    def __init__(self):
        super().__init__(message=self.message)


class RateLimitError(APIStatusError):
    status_code: Literal[429] = 429


class APIMaintenanceMode(APIStatusError):
    status_code: Literal[404] = 404
    error_code: Literal[9999] = 9999


class QueueFullError(APIStatusError):
    status_code: Literal[503] = 503
    error_code: Literal[14] = 14


class PlaceInQueueError(APIStatusError):
    status_code: Literal[404] = 404
    error_code: Literal[5] = 5


class InvalidArgumentError(APIError):
    def __init__(self, e: grpc.RpcError):
        super().__init__(
            message="Invalid Args. Please check model name and other parameters"
        )


class ModelUnavailableError(APIError):
    def __init__(self, e: grpc.RpcError):
        super().__init__(message="Requested model maybe currently offline")


class AuthTokenError(APIError):
    def __init__(self):
        super().__init__(
            message="Key not found. Please set env variable GROQ_SECRET_ACCESS_KEY with the unique secret"
        )


# except grpc.RpcError as e:
#             if e.code() == grpc.StatusCode.INVALID_ARGUMENT:
#                 print("Invalid Args. Please check model name and other params")
#             elif e.code() == grpc.StatusCode.UNAVAILABLE:
#                 print(
#                     f"grpc error: {e.details()}. Requested model maybe currently offline."
#                 )
#             else:
#                 raise e
#             return "", "", {}



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from public.llmcloud.queuestatemanager.v1 import (
    queuestatemanager_pb2 as public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2,
)


class QueueStateManagerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetRequestState = channel.unary_unary(
            "/public.llmcloud.queuestatemanager.v1.QueueStateManagerService/GetRequestState",
            request_serializer=public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2.GetRequestStateRequest.SerializeToString,
            response_deserializer=public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2.GetRequestStateResponse.FromString,
        )


class QueueStateManagerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetRequestState(self, request, context):
        """Returns the request's place in the queue"""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_QueueStateManagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetRequestState": grpc.unary_unary_rpc_method_handler(
            servicer.GetRequestState,
            request_deserializer=public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2.GetRequestStateRequest.FromString,
            response_serializer=public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2.GetRequestStateResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "public.llmcloud.queuestatemanager.v1.QueueStateManagerService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class QueueStateManagerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetRequestState(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/public.llmcloud.queuestatemanager.v1.QueueStateManagerService/GetRequestState",
            public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2.GetRequestStateRequest.SerializeToString,
            public_dot_llmcloud_dot_queuestatemanager_dot_v1_dot_queuestatemanager__pb2.GetRequestStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/queuestatemanager/v1/queuestatemanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n<public/llmcloud/queuestatemanager/v1/queuestatemanager.proto\x12$public.llmcloud.queuestatemanager.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto"0\n\x16GetRequestStateRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id"O\n\x17GetRequestStateResponse\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12$\n\x0eplace_in_queue\x18\x02 \x01(\x05R\x0cplaceInQueue2\xdf\x01\n\x18QueueStateManagerService\x12\xc2\x01\n\x0fGetRequestState\x12<.public.llmcloud.queuestatemanager.v1.GetRequestStateRequest\x1a=.public.llmcloud.queuestatemanager.v1.GetRequestStateResponse"2\x82\xd3\xe4\x93\x02,\x12*/v1/queue_state_manager/request_state/{id}B\xcc\x02\n(com.public.llmcloud.queuestatemanager.v1B\x16QueuestatemanagerProtoP\x01ZSgit.groq.io/cloud/go-proto/public/llmcloud/queuestatemanager/v1;queuestatemanagerv1\xa2\x02\x03PLQ\xaa\x02$Public.Llmcloud.Queuestatemanager.V1\xca\x02%Public_\\Llmcloud\\Queuestatemanager\\V1\xe2\x02\x31Public_\\Llmcloud\\Queuestatemanager\\V1\\GPBMetadata\xea\x02\'Public::Llmcloud::Queuestatemanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.queuestatemanager.v1.queuestatemanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n(com.public.llmcloud.queuestatemanager.v1B\026QueuestatemanagerProtoP\001ZSgit.groq.io/cloud/go-proto/public/llmcloud/queuestatemanager/v1;queuestatemanagerv1\242\002\003PLQ\252\002$Public.Llmcloud.Queuestatemanager.V1\312\002%Public_\\Llmcloud\\Queuestatemanager\\V1\342\0021Public_\\Llmcloud\\Queuestatemanager\\V1\\GPBMetadata\352\002'Public::Llmcloud::Queuestatemanager::V1"
    _globals["_GETREQUESTSTATEREQUEST"].fields_by_name["id"]._options = None
    _globals["_GETREQUESTSTATEREQUEST"].fields_by_name[
        "id"
    ]._serialized_options = b"\272H\003\310\001\001"
    _globals["_QUEUESTATEMANAGERSERVICE"].methods_by_name[
        "GetRequestState"
    ]._options = None
    _globals["_QUEUESTATEMANAGERSERVICE"].methods_by_name[
        "GetRequestState"
    ]._serialized_options = (
        b"\202\323\344\223\002,\022*/v1/queue_state_manager/request_state/{id}"
    )
    _globals["_GETREQUESTSTATEREQUEST"]._serialized_start = 161
    _globals["_GETREQUESTSTATEREQUEST"]._serialized_end = 209
    _globals["_GETREQUESTSTATERESPONSE"]._serialized_start = 211
    _globals["_GETREQUESTSTATERESPONSE"]._serialized_end = 290
    _globals["_QUEUESTATEMANAGERSERVICE"]._serialized_start = 293
    _globals["_QUEUESTATEMANAGERSERVICE"]._serialized_end = 516
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from public.llmcloud.globalstatsmanager.v1 import (
    globalstatsmanager_pb2 as public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2,
)


class GlobalStatsManagerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetGlobalStats = channel.unary_unary(
            "/public.llmcloud.globalstatsmanager.v1.GlobalStatsManagerService/GetGlobalStats",
            request_serializer=public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2.GetGlobalStatsRequest.SerializeToString,
            response_deserializer=public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2.GetGlobalStatsResponse.FromString,
        )


class GlobalStatsManagerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetGlobalStats(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_GlobalStatsManagerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetGlobalStats": grpc.unary_unary_rpc_method_handler(
            servicer.GetGlobalStats,
            request_deserializer=public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2.GetGlobalStatsRequest.FromString,
            response_serializer=public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2.GetGlobalStatsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "public.llmcloud.globalstatsmanager.v1.GlobalStatsManagerService",
        rpc_method_handlers,
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class GlobalStatsManagerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetGlobalStats(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/public.llmcloud.globalstatsmanager.v1.GlobalStatsManagerService/GetGlobalStats",
            public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2.GetGlobalStatsRequest.SerializeToString,
            public_dot_llmcloud_dot_globalstatsmanager_dot_v1_dot_globalstatsmanager__pb2.GetGlobalStatsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/globalstatsmanager/v1/globalstatsmanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n>public/llmcloud/globalstatsmanager/v1/globalstatsmanager.proto\x12%public.llmcloud.globalstatsmanager.v1\x1a\x1cgoogle/api/annotations.proto"\x17\n\x15GetGlobalStatsRequest"N\n\x16GetGlobalStatsResponse\x12\x34\n\x16total_requests_counter\x18\x01 \x01(\rR\x14totalRequestsCounter2\xda\x01\n\x19GlobalStatsManagerService\x12\xbc\x01\n\x0eGetGlobalStats\x12<.public.llmcloud.globalstatsmanager.v1.GetGlobalStatsRequest\x1a=.public.llmcloud.globalstatsmanager.v1.GetGlobalStatsResponse"-\x82\xd3\xe4\x93\x02\'\x12%/v1/global_stats_manager/global_statsB\xd4\x02\n)com.public.llmcloud.globalstatsmanager.v1B\x17GlobalstatsmanagerProtoP\x01ZUgit.groq.io/cloud/go-proto/public/llmcloud/globalstatsmanager/v1;globalstatsmanagerv1\xa2\x02\x03PLG\xaa\x02%Public.Llmcloud.Globalstatsmanager.V1\xca\x02&Public_\\Llmcloud\\Globalstatsmanager\\V1\xe2\x02\x32Public_\\Llmcloud\\Globalstatsmanager\\V1\\GPBMetadata\xea\x02(Public::Llmcloud::Globalstatsmanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.globalstatsmanager.v1.globalstatsmanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n)com.public.llmcloud.globalstatsmanager.v1B\027GlobalstatsmanagerProtoP\001ZUgit.groq.io/cloud/go-proto/public/llmcloud/globalstatsmanager/v1;globalstatsmanagerv1\242\002\003PLG\252\002%Public.Llmcloud.Globalstatsmanager.V1\312\002&Public_\\Llmcloud\\Globalstatsmanager\\V1\342\0022Public_\\Llmcloud\\Globalstatsmanager\\V1\\GPBMetadata\352\002(Public::Llmcloud::Globalstatsmanager::V1"
    _globals["_GLOBALSTATSMANAGERSERVICE"].methods_by_name[
        "GetGlobalStats"
    ]._options = None
    _globals["_GLOBALSTATSMANAGERSERVICE"].methods_by_name[
        "GetGlobalStats"
    ]._serialized_options = (
        b"\202\323\344\223\002'\022%/v1/global_stats_manager/global_stats"
    )
    _globals["_GETGLOBALSTATSREQUEST"]._serialized_start = 135
    _globals["_GETGLOBALSTATSREQUEST"]._serialized_end = 158
    _globals["_GETGLOBALSTATSRESPONSE"]._serialized_start = 160
    _globals["_GETGLOBALSTATSRESPONSE"]._serialized_end = 238
    _globals["_GLOBALSTATSMANAGERSERVICE"]._serialized_start = 241
    _globals["_GLOBALSTATSMANAGERSERVICE"]._serialized_end = 459
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: buf/validate/priv/private.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1f\x62uf/validate/priv/private.proto\x12\x11\x62uf.validate.priv\x1a google/protobuf/descriptor.proto"C\n\x10\x46ieldConstraints\x12/\n\x03\x63\x65l\x18\x01 \x03(\x0b\x32\x1d.buf.validate.priv.ConstraintR\x03\x63\x65l"V\n\nConstraint\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x18\n\x07message\x18\x02 \x01(\tR\x07message\x12\x1e\n\nexpression\x18\x03 \x01(\tR\nexpression:\\\n\x05\x66ield\x12\x1d.google.protobuf.FieldOptions\x18\x88\t \x01(\x0b\x32#.buf.validate.priv.FieldConstraintsR\x05\x66ield\x88\x01\x01\x42\xd9\x01\n\x15\x63om.buf.validate.privB\x0cPrivateProtoP\x01ZLbuf.build/gen/go/bufbuild/protovalidate/protocolbuffers/go/buf/validate/priv\xa2\x02\x03\x42VP\xaa\x02\x11\x42uf.Validate.Priv\xca\x02\x11\x42uf\\Validate\\Priv\xe2\x02\x1d\x42uf\\Validate\\Priv\\GPBMetadata\xea\x02\x13\x42uf::Validate::Privb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "buf.validate.priv.private_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b"\n\025com.buf.validate.privB\014PrivateProtoP\001ZLbuf.build/gen/go/bufbuild/protovalidate/protocolbuffers/go/buf/validate/priv\242\002\003BVP\252\002\021Buf.Validate.Priv\312\002\021Buf\\Validate\\Priv\342\002\035Buf\\Validate\\Priv\\GPBMetadata\352\002\023Buf::Validate::Priv"
    _globals["_FIELDCONSTRAINTS"]._serialized_start = 88
    _globals["_FIELDCONSTRAINTS"]._serialized_end = 155
    _globals["_CONSTRAINT"]._serialized_start = 157
    _globals["_CONSTRAINT"]._serialized_end = 243
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/requestmanager/v1/requestmanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n6public/llmcloud/requestmanager/v1/requestmanager.proto\x12!public.llmcloud.requestmanager.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto"\xd9\x01\n\x1fGetTextCompletionStreamResponse\x12"\n\nrequest_id\x18\x01 \x01(\tH\x00R\trequestId\x88\x01\x01\x12\x1d\n\x07\x63ontent\x18\x02 \x01(\tH\x01R\x07\x63ontent\x88\x01\x01\x12N\n\x05stats\x18\x03 \x01(\x0b\x32\x33.public.llmcloud.requestmanager.v1.PerformanceStatsH\x02R\x05stats\x88\x01\x01\x42\r\n\x0b_request_idB\n\n\x08_contentB\x08\n\x06_stats"\xd6\t\n\x18GetTextCompletionRequest\x12!\n\x08model_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07modelId\x12(\n\rsystem_prompt\x18\x02 \x01(\tH\x00R\x0csystemPrompt\x88\x01\x01\x12\x64\n\x07history\x18\x03 \x03(\x0b\x32J.public.llmcloud.requestmanager.v1.GetTextCompletionRequest.HistoryMessageR\x07history\x12\'\n\x0buser_prompt\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nuserPrompt\x12\x17\n\x04seed\x18\x05 \x01(\rH\x01R\x04seed\x88\x01\x01\x12-\n\nmax_tokens\x18\x06 \x01(\rB\t\xbaH\x06*\x04\x10\x80\x80\x04H\x02R\tmaxTokens\x88\x01\x01\x12\x36\n\x0btemperature\x18\x07 \x01(\x02\x42\x0f\xbaH\x0c\n\n\x1d\x00\x00\x00@%\x00\x00\x00\x00H\x03R\x0btemperature\x88\x01\x01\x12)\n\x05top_p\x18\x08 \x01(\x02\x42\x0f\xbaH\x0c\n\n\x1d\x00\x00\x80?-\x00\x00\x00\x00H\x04R\x04topP\x88\x01\x01\x12%\n\x05top_k\x18\t \x01(\rB\x0b\xbaH\x08*\x06\x18\x80\xfa\x01(\x00H\x05R\x04topK\x88\x01\x01\x12\x30\n\x11\x66requency_penalty\x18\n \x01(\x02H\x06R\x10\x66requencyPenalty\x88\x01\x01\x12i\n\nlogit_bias\x18\x0b \x03(\x0b\x32J.public.llmcloud.requestmanager.v1.GetTextCompletionRequest.LogitBiasEntryR\tlogitBias\x12\x11\n\x01n\x18\x0c \x01(\rH\x07R\x01n\x88\x01\x01\x12.\n\x10presence_penalty\x18\r \x01(\x02H\x08R\x0fpresencePenalty\x88\x01\x01\x12\x12\n\x04stop\x18\x0e \x03(\tR\x04stop\x12-\n\x10max_input_tokens\x18\x0f \x01(\rH\tR\x0emaxInputTokens\x88\x01\x01\x1a`\n\x0eHistoryMessage\x12\x1f\n\x0buser_prompt\x18\x01 \x01(\tR\nuserPrompt\x12-\n\x12\x61ssistant_response\x18\x02 \x01(\tR\x11\x61ssistantResponse\x1a<\n\x0eLogitBiasEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01:\xb4\x01\xbaH\xb0\x01\x1a\xad\x01\n(get_text_completion_request.query_length\x12\x45user_prompt length plus system_prompt length must be less than 262144\x1a:size(this.user_prompt) + size(this.system_prompt) < 262144B\x10\n\x0e_system_promptB\x07\n\x05_seedB\r\n\x0b_max_tokensB\x0e\n\x0c_temperatureB\x08\n\x06_top_pB\x08\n\x06_top_kB\x14\n\x12_frequency_penaltyB\x04\n\x02_nB\x13\n\x11_presence_penaltyB\x13\n\x11_max_input_tokens"\x9f\x01\n\x19GetTextCompletionResponse\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\x12\x18\n\x07\x63ontent\x18\x02 \x01(\tR\x07\x63ontent\x12I\n\x05stats\x18\x03 \x01(\x0b\x32\x33.public.llmcloud.requestmanager.v1.PerformanceStatsR\x05stats"\xb6\x01\n\x10PerformanceStats\x12%\n\x0etime_generated\x18\x01 \x01(\x01R\rtimeGenerated\x12)\n\x10tokens_generated\x18\x02 \x01(\rR\x0ftokensGenerated\x12%\n\x0etime_processed\x18\x03 \x01(\x01R\rtimeProcessed\x12)\n\x10tokens_processed\x18\x04 \x01(\rR\x0ftokensProcessed2\xac\x03\n\x15RequestManagerService\x12\xcc\x01\n\x17GetTextCompletionStream\x12;.public.llmcloud.requestmanager.v1.GetTextCompletionRequest\x1a\x42.public.llmcloud.requestmanager.v1.GetTextCompletionStreamResponse".\x82\xd3\xe4\x93\x02("#/v1/request_manager/text_completion:\x01*0\x01\x12\xc3\x01\n\x11GetTextCompletion\x12;.public.llmcloud.requestmanager.v1.GetTextCompletionRequest\x1a<.public.llmcloud.requestmanager.v1.GetTextCompletionResponse"3\x82\xd3\xe4\x93\x02-"(/v1/request_manager/text_completion_full:\x01*B\xb4\x02\n%com.public.llmcloud.requestmanager.v1B\x13RequestmanagerProtoP\x01ZMgit.groq.io/cloud/go-proto/public/llmcloud/requestmanager/v1;requestmanagerv1\xa2\x02\x03PLR\xaa\x02!Public.Llmcloud.Requestmanager.V1\xca\x02"Public_\\Llmcloud\\Requestmanager\\V1\xe2\x02.Public_\\Llmcloud\\Requestmanager\\V1\\GPBMetadata\xea\x02$Public::Llmcloud::Requestmanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.requestmanager.v1.requestmanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b'\n%com.public.llmcloud.requestmanager.v1B\023RequestmanagerProtoP\001ZMgit.groq.io/cloud/go-proto/public/llmcloud/requestmanager/v1;requestmanagerv1\242\002\003PLR\252\002!Public.Llmcloud.Requestmanager.V1\312\002"Public_\\Llmcloud\\Requestmanager\\V1\342\002.Public_\\Llmcloud\\Requestmanager\\V1\\GPBMetadata\352\002$Public::Llmcloud::Requestmanager::V1'
    _globals["_GETTEXTCOMPLETIONREQUEST_LOGITBIASENTRY"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST_LOGITBIASENTRY"]._serialized_options = b"8\001"
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name["model_id"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name[
        "model_id"
    ]._serialized_options = b"\272H\003\310\001\001"
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name["user_prompt"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name[
        "user_prompt"
    ]._serialized_options = b"\272H\003\310\001\001"
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name["max_tokens"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name[
        "max_tokens"
    ]._serialized_options = b"\272H\006*\004\020\200\200\004"
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name["temperature"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name[
        "temperature"
    ]._serialized_options = b"\272H\014\n\n\035\000\000\000@%\000\000\000\000"
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name["top_p"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name[
        "top_p"
    ]._serialized_options = b"\272H\014\n\n\035\000\000\200?-\000\000\000\000"
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name["top_k"]._options = None
    _globals["_GETTEXTCOMPLETIONREQUEST"].fields_by_name[
        "top_k"
    ]._serialized_options = b"\272H\010*\006\030\200\372\001(\000"
    _globals["_GETTEXTCOMPLETIONREQUEST"]._options = None
    _globals[
        "_GETTEXTCOMPLETIONREQUEST"
    ]._serialized_options = b"\272H\260\001\032\255\001\n(get_text_completion_request.query_length\022Euser_prompt length plus system_prompt length must be less than 262144\032:size(this.user_prompt) + size(this.system_prompt) < 262144"
    _globals["_REQUESTMANAGERSERVICE"].methods_by_name[
        "GetTextCompletionStream"
    ]._options = None
    _globals["_REQUESTMANAGERSERVICE"].methods_by_name[
        "GetTextCompletionStream"
    ]._serialized_options = (
        b'\202\323\344\223\002("#/v1/request_manager/text_completion:\001*'
    )
    _globals["_REQUESTMANAGERSERVICE"].methods_by_name[
        "GetTextCompletion"
    ]._options = None
    _globals["_REQUESTMANAGERSERVICE"].methods_by_name[
        "GetTextCompletion"
    ]._serialized_options = (
        b'\202\323\344\223\002-"(/v1/request_manager/text_completion_full:\001*'
    )
    _globals["_GETTEXTCOMPLETIONSTREAMRESPONSE"]._serialized_start = 153
    _globals["_GETTEXTCOMPLETIONSTREAMRESPONSE"]._serialized_end = 370
    _globals["_GETTEXTCOMPLETIONREQUEST"]._serialized_start = 373
    _globals["_GETTEXTCOMPLETIONREQUEST"]._serialized_end = 1611
    _globals["_GETTEXTCOMPLETIONREQUEST_HISTORYMESSAGE"]._serialized_start = 1122
    _globals["_GETTEXTCOMPLETIONREQUEST_HISTORYMESSAGE"]._serialized_end = 1218
    _globals["_GETTEXTCOMPLETIONREQUEST_LOGITBIASENTRY"]._serialized_start = 1220
    _globals["_GETTEXTCOMPLETIONREQUEST_LOGITBIASENTRY"]._serialized_end = 1280
    _globals["_GETTEXTCOMPLETIONRESPONSE"]._serialized_start = 1614
    _globals["_GETTEXTCOMPLETIONRESPONSE"]._serialized_end = 1773
    _globals["_PERFORMANCESTATS"]._serialized_start = 1776
    _globals["_PERFORMANCESTATS"]._serialized_end = 1958
    _globals["_REQUESTMANAGERSERVICE"]._serialized_start = 1961
    _globals["_REQUESTMANAGERSERVICE"]._serialized_end = 2389
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: public/llmcloud/modelmanager/v1/modelmanager.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from public.llmcloud.modelmanager.v1 import (
    model_pb2 as public_dot_llmcloud_dot_modelmanager_dot_v1_dot_model__pb2,
)

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n2public/llmcloud/modelmanager/v1/modelmanager.proto\x12\x1fpublic.llmcloud.modelmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a+public/llmcloud/modelmanager/v1/model.proto"\x13\n\x11ListModelsRequest"T\n\x12ListModelsResponse\x12>\n\x06models\x18\x01 \x03(\x0b\x32&.public.llmcloud.modelmanager.v1.ModelR\x06models2\xaf\x01\n\x13ModelManagerService\x12\x97\x01\n\nListModels\x12\x32.public.llmcloud.modelmanager.v1.ListModelsRequest\x1a\x33.public.llmcloud.modelmanager.v1.ListModelsResponse" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/model_manager/modelsB\xa4\x02\n#com.public.llmcloud.modelmanager.v1B\x11ModelmanagerProtoP\x01ZIgit.groq.io/cloud/go-proto/public/llmcloud/modelmanager/v1;modelmanagerv1\xa2\x02\x03PLM\xaa\x02\x1fPublic.Llmcloud.Modelmanager.V1\xca\x02 Public_\\Llmcloud\\Modelmanager\\V1\xe2\x02,Public_\\Llmcloud\\Modelmanager\\V1\\GPBMetadata\xea\x02"Public::Llmcloud::Modelmanager::V1b\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "public.llmcloud.modelmanager.v1.modelmanager_pb2", _globals
)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals[
        "DESCRIPTOR"
    ]._serialized_options = b'\n#com.public.llmcloud.modelmanager.v1B\021ModelmanagerProtoP\001ZIgit.groq.io/cloud/go-proto/public/llmcloud/modelmanager/v1;modelmanagerv1\242\002\003PLM\252\002\037Public.Llmcloud.Modelmanager.V1\312\002 Public_\\Llmcloud\\Modelmanager\\V1\342\002,Public_\\Llmcloud\\Modelmanager\\V1\\GPBMetadata\352\002"Public::Llmcloud::Modelmanager::V1'
    _globals["_MODELMANAGERSERVICE"].methods_by_name["ListModels"]._options = None
    _globals["_MODELMANAGERSERVICE"].methods_by_name[
        "ListModels"
    ]._serialized_options = b"\202\323\344\223\002\032\022\030/v1/model_manager/models"
    _globals["_LISTMODELSREQUEST"]._serialized_start = 162
    _globals["_LISTMODELSREQUEST"]._serialized_end = 181
    _globals["_LISTMODELSRESPONSE"]._serialized_start = 183
    _globals["_LISTMODELSRESPONSE"]._serialized_end = 267
    _globals["_MODELMANAGERSERVICE"]._serialized_start = 270
    _globals["_MODELMANAGERSERVICE"]._serialized_end = 445
# @@protoc_insertion_point(module_scope)
